A generic behaviour for implementing Splunk clients for
OffBroadway.Splunk.Producer.
This module defines callbacks to normalize options and receive items for a Splunk job.
Modules that implements this behaviour should be passed as the
:splunk_client option from OffBroadway.Splunk.Producer.
Summary
Types
@type messages() :: [Broadway.Message.t()]
Callbacks
@callback ack_message(message :: Broadway.Message.t(), ack_options :: any()) :: any()
@callback receive_messages(sid :: binary(), demand :: pos_integer(), opts :: any()) :: {:ok, messages()} | {:error, reason :: any()}